===========
oboyo
===========

.. image:: https://img.shields.io/github/repo-size/coatk1/oboyo
 :target: https://github.com/coatk1/oboyo

.. image:: https://github.com/coatk1/oboyo/workflows/Check/badge.svg
 :target: https://github.com/coatk1/oboyo/actions?query=workflow%3ACheck

.. image:: https://anaconda.org/coatk1/oboyo/badges/version.svg
 :target: https://anaconda.org/coatk1/oboyo

.. image:: https://anaconda.org/coatk1/oboyo/badges/latest_release_date.svg
 :target: https://anaconda.org/coatk1/oboyo/files

.. image:: https://img.shields.io/conda/v/coatk1/oboyo
 :target: https://anaconda.org/coatk1/oboyo

.. image:: https://img.shields.io/pypi/v/oboyo
 :target: https://pypi.org/project/oboyo/

.. image:: https://img.shields.io/codeclimate/maintainability/coatk1/oboyo 
  :target: https://codeclimate.com/github/coatk1/oboyo

.. image:: https://img.shields.io/codeclimate/coverage/coatk1/oboyo   
  :target: https://codeclimate.com/github/coatk1/oboyo

.. image:: https://img.shields.io/github/license/coatk1/oboyo 
  :target: https://github.com/coatk1/oboyo/blob/main/LICENSE


Python package for testing
